# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_exchange_rpc_pb2 as exchange_dot_injective__exchange__rpc__pb2


class InjectiveExchangeRPCStub(object):
    """InjectiveExchangeRPC defines gRPC API of an Injective Exchange service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTx = channel.unary_unary(
                '/injective_exchange_rpc.InjectiveExchangeRPC/GetTx',
                request_serializer=exchange_dot_injective__exchange__rpc__pb2.GetTxRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__exchange__rpc__pb2.GetTxResponse.FromString,
                _registered_method=True)
        self.PrepareTx = channel.unary_unary(
                '/injective_exchange_rpc.InjectiveExchangeRPC/PrepareTx',
                request_serializer=exchange_dot_injective__exchange__rpc__pb2.PrepareTxRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__exchange__rpc__pb2.PrepareTxResponse.FromString,
                _registered_method=True)
        self.PrepareEip712 = channel.unary_unary(
                '/injective_exchange_rpc.InjectiveExchangeRPC/PrepareEip712',
                request_serializer=exchange_dot_injective__exchange__rpc__pb2.PrepareEip712Request.SerializeToString,
                response_deserializer=exchange_dot_injective__exchange__rpc__pb2.PrepareEip712Response.FromString,
                _registered_method=True)
        self.BroadcastTx = channel.unary_unary(
                '/injective_exchange_rpc.InjectiveExchangeRPC/BroadcastTx',
                request_serializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastTxRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastTxResponse.FromString,
                _registered_method=True)
        self.PrepareCosmosTx = channel.unary_unary(
                '/injective_exchange_rpc.InjectiveExchangeRPC/PrepareCosmosTx',
                request_serializer=exchange_dot_injective__exchange__rpc__pb2.PrepareCosmosTxRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__exchange__rpc__pb2.PrepareCosmosTxResponse.FromString,
                _registered_method=True)
        self.BroadcastCosmosTx = channel.unary_unary(
                '/injective_exchange_rpc.InjectiveExchangeRPC/BroadcastCosmosTx',
                request_serializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastCosmosTxRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastCosmosTxResponse.FromString,
                _registered_method=True)
        self.GetFeePayer = channel.unary_unary(
                '/injective_exchange_rpc.InjectiveExchangeRPC/GetFeePayer',
                request_serializer=exchange_dot_injective__exchange__rpc__pb2.GetFeePayerRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__exchange__rpc__pb2.GetFeePayerResponse.FromString,
                _registered_method=True)


class InjectiveExchangeRPCServicer(object):
    """InjectiveExchangeRPC defines gRPC API of an Injective Exchange service.
    """

    def GetTx(self, request, context):
        """GetTx gets transaction details by hash.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrepareTx(self, request, context):
        """PrepareTx generates a Web3-signable body for a Cosmos transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrepareEip712(self, request, context):
        """prepareEip712 generates EIP712 for an Injective Message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BroadcastTx(self, request, context):
        """BroadcastTx broadcasts a signed Web3 transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrepareCosmosTx(self, request, context):
        """PrepareCosmosTx generates a Web3-signable body for a Cosmos transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BroadcastCosmosTx(self, request, context):
        """BroadcastCosmosTx broadcasts a signed Web3 transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeePayer(self, request, context):
        """Return fee payer information's
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveExchangeRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTx': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTx,
                    request_deserializer=exchange_dot_injective__exchange__rpc__pb2.GetTxRequest.FromString,
                    response_serializer=exchange_dot_injective__exchange__rpc__pb2.GetTxResponse.SerializeToString,
            ),
            'PrepareTx': grpc.unary_unary_rpc_method_handler(
                    servicer.PrepareTx,
                    request_deserializer=exchange_dot_injective__exchange__rpc__pb2.PrepareTxRequest.FromString,
                    response_serializer=exchange_dot_injective__exchange__rpc__pb2.PrepareTxResponse.SerializeToString,
            ),
            'PrepareEip712': grpc.unary_unary_rpc_method_handler(
                    servicer.PrepareEip712,
                    request_deserializer=exchange_dot_injective__exchange__rpc__pb2.PrepareEip712Request.FromString,
                    response_serializer=exchange_dot_injective__exchange__rpc__pb2.PrepareEip712Response.SerializeToString,
            ),
            'BroadcastTx': grpc.unary_unary_rpc_method_handler(
                    servicer.BroadcastTx,
                    request_deserializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastTxRequest.FromString,
                    response_serializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastTxResponse.SerializeToString,
            ),
            'PrepareCosmosTx': grpc.unary_unary_rpc_method_handler(
                    servicer.PrepareCosmosTx,
                    request_deserializer=exchange_dot_injective__exchange__rpc__pb2.PrepareCosmosTxRequest.FromString,
                    response_serializer=exchange_dot_injective__exchange__rpc__pb2.PrepareCosmosTxResponse.SerializeToString,
            ),
            'BroadcastCosmosTx': grpc.unary_unary_rpc_method_handler(
                    servicer.BroadcastCosmosTx,
                    request_deserializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastCosmosTxRequest.FromString,
                    response_serializer=exchange_dot_injective__exchange__rpc__pb2.BroadcastCosmosTxResponse.SerializeToString,
            ),
            'GetFeePayer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeePayer,
                    request_deserializer=exchange_dot_injective__exchange__rpc__pb2.GetFeePayerRequest.FromString,
                    response_serializer=exchange_dot_injective__exchange__rpc__pb2.GetFeePayerResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_exchange_rpc.InjectiveExchangeRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_exchange_rpc.InjectiveExchangeRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveExchangeRPC(object):
    """InjectiveExchangeRPC defines gRPC API of an Injective Exchange service.
    """

    @staticmethod
    def GetTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_exchange_rpc.InjectiveExchangeRPC/GetTx',
            exchange_dot_injective__exchange__rpc__pb2.GetTxRequest.SerializeToString,
            exchange_dot_injective__exchange__rpc__pb2.GetTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PrepareTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_exchange_rpc.InjectiveExchangeRPC/PrepareTx',
            exchange_dot_injective__exchange__rpc__pb2.PrepareTxRequest.SerializeToString,
            exchange_dot_injective__exchange__rpc__pb2.PrepareTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PrepareEip712(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_exchange_rpc.InjectiveExchangeRPC/PrepareEip712',
            exchange_dot_injective__exchange__rpc__pb2.PrepareEip712Request.SerializeToString,
            exchange_dot_injective__exchange__rpc__pb2.PrepareEip712Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BroadcastTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_exchange_rpc.InjectiveExchangeRPC/BroadcastTx',
            exchange_dot_injective__exchange__rpc__pb2.BroadcastTxRequest.SerializeToString,
            exchange_dot_injective__exchange__rpc__pb2.BroadcastTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PrepareCosmosTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_exchange_rpc.InjectiveExchangeRPC/PrepareCosmosTx',
            exchange_dot_injective__exchange__rpc__pb2.PrepareCosmosTxRequest.SerializeToString,
            exchange_dot_injective__exchange__rpc__pb2.PrepareCosmosTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BroadcastCosmosTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_exchange_rpc.InjectiveExchangeRPC/BroadcastCosmosTx',
            exchange_dot_injective__exchange__rpc__pb2.BroadcastCosmosTxRequest.SerializeToString,
            exchange_dot_injective__exchange__rpc__pb2.BroadcastCosmosTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFeePayer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_exchange_rpc.InjectiveExchangeRPC/GetFeePayer',
            exchange_dot_injective__exchange__rpc__pb2.GetFeePayerRequest.SerializeToString,
            exchange_dot_injective__exchange__rpc__pb2.GetFeePayerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.params.v1beta1 import params_pb2 as cosmos_dot_params_dot_v1beta1_dot_params__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/params/v1beta1/query.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"cosmos/params/v1beta1/params.proto\x1a\x11\x61mino/amino.proto\"B\n\x12QueryParamsRequest\x12\x1a\n\x08subspace\x18\x01 \x01(\tR\x08subspace\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"Z\n\x13QueryParamsResponse\x12\x43\n\x05param\x18\x01 \x01(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x05param\"\x17\n\x15QuerySubspacesRequest\"W\n\x16QuerySubspacesResponse\x12=\n\tsubspaces\x18\x01 \x03(\x0b\x32\x1f.cosmos.params.v1beta1.SubspaceR\tsubspaces\":\n\x08Subspace\x12\x1a\n\x08subspace\x18\x01 \x01(\tR\x08subspace\x12\x12\n\x04keys\x18\x02 \x03(\tR\x04keys2\xa5\x02\n\x05Query\x12\x86\x01\n\x06Params\x12).cosmos.params.v1beta1.QueryParamsRequest\x1a*.cosmos.params.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/params/v1beta1/params\x12\x92\x01\n\tSubspaces\x12,.cosmos.params.v1beta1.QuerySubspacesRequest\x1a-.cosmos.params.v1beta1.QuerySubspacesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmos/params/v1beta1/subspacesB\xd3\x01\n\x19\x63om.cosmos.params.v1beta1B\nQueryProtoP\x01Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\xa2\x02\x03\x43PX\xaa\x02\x15\x43osmos.Params.V1beta1\xca\x02\x15\x43osmos\\Params\\V1beta1\xe2\x02!Cosmos\\Params\\V1beta1\\GPBMetadata\xea\x02\x17\x43osmos::Params::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cosmos.params.v1beta1B\nQueryProtoP\001Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\242\002\003CPX\252\002\025Cosmos.Params.V1beta1\312\002\025Cosmos\\Params\\V1beta1\342\002!Cosmos\\Params\\V1beta1\\GPBMetadata\352\002\027Cosmos::Params::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['param']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['param']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/params/v1beta1/params'
  _globals['_QUERY'].methods_by_name['Subspaces']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Subspaces']._serialized_options = b'\202\323\344\223\002\"\022 /cosmos/params/v1beta1/subspaces'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=167
  _globals['_QUERYPARAMSREQUEST']._serialized_end=233
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=235
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=325
  _globals['_QUERYSUBSPACESREQUEST']._serialized_start=327
  _globals['_QUERYSUBSPACESREQUEST']._serialized_end=350
  _globals['_QUERYSUBSPACESRESPONSE']._serialized_start=352
  _globals['_QUERYSUBSPACESRESPONSE']._serialized_end=439
  _globals['_SUBSPACE']._serialized_start=441
  _globals['_SUBSPACE']._serialized_end=499
  _globals['_QUERY']._serialized_start=502
  _globals['_QUERY']._serialized_end=795
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/authz.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/bank/v1beta1/authz.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x9a\x02\n\x11SendAuthorization\x12\x82\x01\n\x0bspend_limit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\nspendLimit\x12\x37\n\nallow_list\x18\x02 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tallowList:G\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*\x1c\x63osmos-sdk/SendAuthorizationB\xbe\x01\n\x17\x63om.cosmos.bank.v1beta1B\nAuthzProtoP\x01Z)github.com/cosmos/cosmos-sdk/x/bank/types\xa2\x02\x03\x43\x42X\xaa\x02\x13\x43osmos.Bank.V1beta1\xca\x02\x13\x43osmos\\Bank\\V1beta1\xe2\x02\x1f\x43osmos\\Bank\\V1beta1\\GPBMetadata\xea\x02\x15\x43osmos::Bank::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.bank.v1beta1B\nAuthzProtoP\001Z)github.com/cosmos/cosmos-sdk/x/bank/types\242\002\003CBX\252\002\023Cosmos.Bank.V1beta1\312\002\023Cosmos\\Bank\\V1beta1\342\002\037Cosmos\\Bank\\V1beta1\\GPBMetadata\352\002\025Cosmos::Bank::V1beta1'
  _globals['_SENDAUTHORIZATION'].fields_by_name['spend_limit']._loaded_options = None
  _globals['_SENDAUTHORIZATION'].fields_by_name['spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_SENDAUTHORIZATION'].fields_by_name['allow_list']._loaded_options = None
  _globals['_SENDAUTHORIZATION'].fields_by_name['allow_list']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_SENDAUTHORIZATION']._loaded_options = None
  _globals['_SENDAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*\034cosmos-sdk/SendAuthorization'
  _globals['_SENDAUTHORIZATION']._serialized_start=157
  _globals['_SENDAUTHORIZATION']._serialized_end=439
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.tokenfactory.v1beta1 import authorityMetadata_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2
from pyinjective.proto.injective.tokenfactory.v1beta1 import params_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,injective/tokenfactory/v1beta1/genesis.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x36injective/tokenfactory/v1beta1/authorityMetadata.proto\x1a+injective/tokenfactory/v1beta1/params.proto\"\xc8\x01\n\x0cGenesisState\x12\x44\n\x06params\x18\x01 \x01(\x0b\x32&.injective.tokenfactory.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12r\n\x0e\x66\x61\x63tory_denoms\x18\x02 \x03(\x0b\x32,.injective.tokenfactory.v1beta1.GenesisDenomB\x1d\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:\"factory_denoms\"R\rfactoryDenoms\"\xc8\x02\n\x0cGenesisDenom\x12&\n\x05\x64\x65nom\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"R\x05\x64\x65nom\x12\x88\x01\n\x12\x61uthority_metadata\x18\x02 \x01(\x0b\x32\x36.injective.tokenfactory.v1beta1.DenomAuthorityMetadataB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"authority_metadata\"R\x11\x61uthorityMetadata\x12#\n\x04name\x18\x03 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"name\"R\x04name\x12)\n\x06symbol\x18\x04 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"symbol\"R\x06symbol\x12/\n\x08\x64\x65\x63imals\x18\x05 \x01(\rB\x13\xf2\xde\x1f\x0fyaml:\"decimals\"R\x08\x64\x65\x63imals:\x04\xe8\xa0\x1f\x01\x42\xa0\x02\n\"com.injective.tokenfactory.v1beta1B\x0cGenesisProtoP\x01ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\xa2\x02\x03ITX\xaa\x02\x1eInjective.Tokenfactory.V1beta1\xca\x02\x1eInjective\\Tokenfactory\\V1beta1\xe2\x02*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\xea\x02 Injective::Tokenfactory::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.injective.tokenfactory.v1beta1B\014GenesisProtoP\001ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\242\002\003ITX\252\002\036Injective.Tokenfactory.V1beta1\312\002\036Injective\\Tokenfactory\\V1beta1\342\002*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\352\002 Injective::Tokenfactory::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['factory_denoms']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['factory_denoms']._serialized_options = b'\310\336\037\000\362\336\037\025yaml:\"factory_denoms\"'
  _globals['_GENESISDENOM'].fields_by_name['denom']._loaded_options = None
  _globals['_GENESISDENOM'].fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _globals['_GENESISDENOM'].fields_by_name['authority_metadata']._loaded_options = None
  _globals['_GENESISDENOM'].fields_by_name['authority_metadata']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"authority_metadata\"'
  _globals['_GENESISDENOM'].fields_by_name['name']._loaded_options = None
  _globals['_GENESISDENOM'].fields_by_name['name']._serialized_options = b'\362\336\037\013yaml:\"name\"'
  _globals['_GENESISDENOM'].fields_by_name['symbol']._loaded_options = None
  _globals['_GENESISDENOM'].fields_by_name['symbol']._serialized_options = b'\362\336\037\ryaml:\"symbol\"'
  _globals['_GENESISDENOM'].fields_by_name['decimals']._loaded_options = None
  _globals['_GENESISDENOM'].fields_by_name['decimals']._serialized_options = b'\362\336\037\017yaml:\"decimals\"'
  _globals['_GENESISDENOM']._loaded_options = None
  _globals['_GENESISDENOM']._serialized_options = b'\350\240\037\001'
  _globals['_GENESISSTATE']._serialized_start=204
  _globals['_GENESISSTATE']._serialized_end=404
  _globals['_GENESISDENOM']._serialized_start=407
  _globals['_GENESISDENOM']._serialized_end=735
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/circuit/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos.circuit.v1 import types_pb2 as cosmos_dot_circuit_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmos/circuit/v1/tx.proto\x12\x11\x63osmos.circuit.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1d\x63osmos/circuit/v1/types.proto\"\xa0\x01\n\x1aMsgAuthorizeCircuitBreaker\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\x12\x18\n\x07grantee\x18\x02 \x01(\tR\x07grantee\x12@\n\x0bpermissions\x18\x03 \x01(\x0b\x32\x1e.cosmos.circuit.v1.PermissionsR\x0bpermissions:\x0c\x82\xe7\xb0*\x07granter\">\n\"MsgAuthorizeCircuitBreakerResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"i\n\x15MsgTripCircuitBreaker\x12\x1c\n\tauthority\x18\x01 \x01(\tR\tauthority\x12\"\n\rmsg_type_urls\x18\x02 \x03(\tR\x0bmsgTypeUrls:\x0e\x82\xe7\xb0*\tauthority\"9\n\x1dMsgTripCircuitBreakerResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"j\n\x16MsgResetCircuitBreaker\x12\x1c\n\tauthority\x18\x01 \x01(\tR\tauthority\x12\"\n\rmsg_type_urls\x18\x03 \x03(\tR\x0bmsgTypeUrls:\x0e\x82\xe7\xb0*\tauthority\":\n\x1eMsgResetCircuitBreakerResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success2\xf4\x02\n\x03Msg\x12\x7f\n\x17\x41uthorizeCircuitBreaker\x12-.cosmos.circuit.v1.MsgAuthorizeCircuitBreaker\x1a\x35.cosmos.circuit.v1.MsgAuthorizeCircuitBreakerResponse\x12p\n\x12TripCircuitBreaker\x12(.cosmos.circuit.v1.MsgTripCircuitBreaker\x1a\x30.cosmos.circuit.v1.MsgTripCircuitBreakerResponse\x12s\n\x13ResetCircuitBreaker\x12).cosmos.circuit.v1.MsgResetCircuitBreaker\x1a\x31.cosmos.circuit.v1.MsgResetCircuitBreakerResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xa4\x01\n\x15\x63om.cosmos.circuit.v1B\x07TxProtoP\x01Z\x1c\x63osmossdk.io/x/circuit/types\xa2\x02\x03\x43\x43X\xaa\x02\x11\x43osmos.Circuit.V1\xca\x02\x11\x43osmos\\Circuit\\V1\xe2\x02\x1d\x43osmos\\Circuit\\V1\\GPBMetadata\xea\x02\x13\x43osmos::Circuit::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.circuit.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cosmos.circuit.v1B\007TxProtoP\001Z\034cosmossdk.io/x/circuit/types\242\002\003CCX\252\002\021Cosmos.Circuit.V1\312\002\021Cosmos\\Circuit\\V1\342\002\035Cosmos\\Circuit\\V1\\GPBMetadata\352\002\023Cosmos::Circuit::V1'
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._loaded_options = None
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_options = b'\202\347\260*\007granter'
  _globals['_MSGTRIPCIRCUITBREAKER']._loaded_options = None
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGRESETCIRCUITBREAKER']._loaded_options = None
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_start=106
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_end=266
  _globals['_MSGAUTHORIZECIRCUITBREAKERRESPONSE']._serialized_start=268
  _globals['_MSGAUTHORIZECIRCUITBREAKERRESPONSE']._serialized_end=330
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_start=332
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_end=437
  _globals['_MSGTRIPCIRCUITBREAKERRESPONSE']._serialized_start=439
  _globals['_MSGTRIPCIRCUITBREAKERRESPONSE']._serialized_end=496
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_start=498
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_end=604
  _globals['_MSGRESETCIRCUITBREAKERRESPONSE']._serialized_start=606
  _globals['_MSGRESETCIRCUITBREAKERRESPONSE']._serialized_end=664
  _globals['_MSG']._serialized_start=667
  _globals['_MSG']._serialized_end=1039
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/health.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x65xchange/health.proto\x12\x06\x61pi.v1\"\x12\n\x10GetStatusRequest\"{\n\x11GetStatusResponse\x12\x0c\n\x01s\x18\x01 \x01(\tR\x01s\x12\x16\n\x06\x65rrmsg\x18\x02 \x01(\tR\x06\x65rrmsg\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x14.api.v1.HealthStatusR\x04\x64\x61ta\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\"\xa4\x02\n\x0cHealthStatus\x12!\n\x0clocal_height\x18\x01 \x01(\x11R\x0blocalHeight\x12\'\n\x0flocal_timestamp\x18\x02 \x01(\x11R\x0elocalTimestamp\x12%\n\x0ehoracle_height\x18\x03 \x01(\x11R\rhoracleHeight\x12+\n\x11horacle_timestamp\x18\x04 \x01(\x11R\x10horacleTimestamp\x12\x34\n\x16migration_last_version\x18\x05 \x01(\x11R\x14migrationLastVersion\x12\x1b\n\tep_height\x18\x06 \x01(\x11R\x08\x65pHeight\x12!\n\x0c\x65p_timestamp\x18\x07 \x01(\x11R\x0b\x65pTimestamp2J\n\x06Health\x12@\n\tGetStatus\x12\x18.api.v1.GetStatusRequest\x1a\x19.api.v1.GetStatusResponseB]\n\ncom.api.v1B\x0bHealthProtoP\x01Z\t/api.v1pb\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.health_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.api.v1B\013HealthProtoP\001Z\t/api.v1pb\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1'
  _globals['_GETSTATUSREQUEST']._serialized_start=33
  _globals['_GETSTATUSREQUEST']._serialized_end=51
  _globals['_GETSTATUSRESPONSE']._serialized_start=53
  _globals['_GETSTATUSRESPONSE']._serialized_end=176
  _globals['_HEALTHSTATUS']._serialized_start=179
  _globals['_HEALTHSTATUS']._serialized_end=471
  _globals['_HEALTH']._serialized_start=473
  _globals['_HEALTH']._serialized_end=547
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ibc/applications/transfer/v1/tx.proto\x12\x1cibc.applications.transfer.v1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1fibc/core/client/v1/client.proto\x1a+ibc/applications/transfer/v1/transfer.proto\"\x80\x03\n\x0bMsgTransfer\x12\x1f\n\x0bsource_port\x18\x01 \x01(\tR\nsourcePort\x12%\n\x0esource_channel\x18\x02 \x01(\tR\rsourceChannel\x12:\n\x05token\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x05token\x12\x16\n\x06sender\x18\x04 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x05 \x01(\tR\x08receiver\x12L\n\x0etimeout_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\rtimeoutHeight\x12+\n\x11timeout_timestamp\x18\x07 \x01(\x04R\x10timeoutTimestamp\x12\x12\n\x04memo\x18\x08 \x01(\tR\x04memo:*\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x16\x63osmos-sdk/MsgTransfer\"7\n\x13MsgTransferResponse\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence:\x04\x88\xa0\x1f\x00\"~\n\x0fMsgUpdateParams\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12\x42\n\x06params\x18\x02 \x01(\x0b\x32$.ibc.applications.transfer.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x19\n\x17MsgUpdateParamsResponse2\xec\x01\n\x03Msg\x12h\n\x08Transfer\x12).ibc.applications.transfer.v1.MsgTransfer\x1a\x31.ibc.applications.transfer.v1.MsgTransferResponse\x12t\n\x0cUpdateParams\x12-.ibc.applications.transfer.v1.MsgUpdateParams\x1a\x35.ibc.applications.transfer.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xf7\x01\n com.ibc.applications.transfer.v1B\x07TxProtoP\x01Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\xa2\x02\x03IAT\xaa\x02\x1cIbc.Applications.Transfer.V1\xca\x02\x1cIbc\\Applications\\Transfer\\V1\xe2\x02(Ibc\\Applications\\Transfer\\V1\\GPBMetadata\xea\x02\x1fIbc::Applications::Transfer::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.ibc.applications.transfer.v1B\007TxProtoP\001Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\242\002\003IAT\252\002\034Ibc.Applications.Transfer.V1\312\002\034Ibc\\Applications\\Transfer\\V1\342\002(Ibc\\Applications\\Transfer\\V1\\GPBMetadata\352\002\037Ibc::Applications::Transfer::V1'
  _globals['_MSGTRANSFER'].fields_by_name['token']._loaded_options = None
  _globals['_MSGTRANSFER'].fields_by_name['token']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGTRANSFER'].fields_by_name['timeout_height']._loaded_options = None
  _globals['_MSGTRANSFER'].fields_by_name['timeout_height']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGTRANSFER']._loaded_options = None
  _globals['_MSGTRANSFER']._serialized_options = b'\210\240\037\000\202\347\260*\006sender\212\347\260*\026cosmos-sdk/MsgTransfer'
  _globals['_MSGTRANSFERRESPONSE']._loaded_options = None
  _globals['_MSGTRANSFERRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGTRANSFER']._serialized_start=248
  _globals['_MSGTRANSFER']._serialized_end=632
  _globals['_MSGTRANSFERRESPONSE']._serialized_start=634
  _globals['_MSGTRANSFERRESPONSE']._serialized_end=689
  _globals['_MSGUPDATEPARAMS']._serialized_start=691
  _globals['_MSGUPDATEPARAMS']._serialized_end=817
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=819
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=844
  _globals['_MSG']._serialized_start=847
  _globals['_MSG']._serialized_end=1083
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/feegrant/v1beta1/tx.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\x89\x02\n\x11MsgGrantAllowance\x12\x32\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07granter\x12\x32\n\x07grantee\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07grantee\x12]\n\tallowance\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB)\xca\xb4-%cosmos.feegrant.v1beta1.FeeAllowanceIR\tallowance:-\x82\xe7\xb0*\x07granter\x8a\xe7\xb0*\x1c\x63osmos-sdk/MsgGrantAllowance\"\x1b\n\x19MsgGrantAllowanceResponse\"\xac\x01\n\x12MsgRevokeAllowance\x12\x32\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07granter\x12\x32\n\x07grantee\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07grantee:.\x82\xe7\xb0*\x07granter\x8a\xe7\xb0*\x1d\x63osmos-sdk/MsgRevokeAllowance\"\x1c\n\x1aMsgRevokeAllowanceResponse\"S\n\x12MsgPruneAllowances\x12\x30\n\x06pruner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06pruner:\x0b\x82\xe7\xb0*\x06pruner\"\x1c\n\x1aMsgPruneAllowancesResponse2\xe8\x02\n\x03Msg\x12p\n\x0eGrantAllowance\x12*.cosmos.feegrant.v1beta1.MsgGrantAllowance\x1a\x32.cosmos.feegrant.v1beta1.MsgGrantAllowanceResponse\x12s\n\x0fRevokeAllowance\x12+.cosmos.feegrant.v1beta1.MsgRevokeAllowance\x1a\x33.cosmos.feegrant.v1beta1.MsgRevokeAllowanceResponse\x12s\n\x0fPruneAllowances\x12+.cosmos.feegrant.v1beta1.MsgPruneAllowances\x1a\x33.cosmos.feegrant.v1beta1.MsgPruneAllowancesResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xbd\x01\n\x1b\x63om.cosmos.feegrant.v1beta1B\x07TxProtoP\x01Z\x17\x63osmossdk.io/x/feegrant\xa2\x02\x03\x43\x46X\xaa\x02\x17\x43osmos.Feegrant.V1beta1\xca\x02\x17\x43osmos\\Feegrant\\V1beta1\xe2\x02#Cosmos\\Feegrant\\V1beta1\\GPBMetadata\xea\x02\x19\x43osmos::Feegrant::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.feegrant.v1beta1B\007TxProtoP\001Z\027cosmossdk.io/x/feegrant\242\002\003CFX\252\002\027Cosmos.Feegrant.V1beta1\312\002\027Cosmos\\Feegrant\\V1beta1\342\002#Cosmos\\Feegrant\\V1beta1\\GPBMetadata\352\002\031Cosmos::Feegrant::V1beta1'
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['granter']._loaded_options = None
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['grantee']._loaded_options = None
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['allowance']._loaded_options = None
  _globals['_MSGGRANTALLOWANCE'].fields_by_name['allowance']._serialized_options = b'\312\264-%cosmos.feegrant.v1beta1.FeeAllowanceI'
  _globals['_MSGGRANTALLOWANCE']._loaded_options = None
  _globals['_MSGGRANTALLOWANCE']._serialized_options = b'\202\347\260*\007granter\212\347\260*\034cosmos-sdk/MsgGrantAllowance'
  _globals['_MSGREVOKEALLOWANCE'].fields_by_name['granter']._loaded_options = None
  _globals['_MSGREVOKEALLOWANCE'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGREVOKEALLOWANCE'].fields_by_name['grantee']._loaded_options = None
  _globals['_MSGREVOKEALLOWANCE'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGREVOKEALLOWANCE']._loaded_options = None
  _globals['_MSGREVOKEALLOWANCE']._serialized_options = b'\202\347\260*\007granter\212\347\260*\035cosmos-sdk/MsgRevokeAllowance'
  _globals['_MSGPRUNEALLOWANCES'].fields_by_name['pruner']._loaded_options = None
  _globals['_MSGPRUNEALLOWANCES'].fields_by_name['pruner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGPRUNEALLOWANCES']._loaded_options = None
  _globals['_MSGPRUNEALLOWANCES']._serialized_options = b'\202\347\260*\006pruner'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGGRANTALLOWANCE']._serialized_start=160
  _globals['_MSGGRANTALLOWANCE']._serialized_end=425
  _globals['_MSGGRANTALLOWANCERESPONSE']._serialized_start=427
  _globals['_MSGGRANTALLOWANCERESPONSE']._serialized_end=454
  _globals['_MSGREVOKEALLOWANCE']._serialized_start=457
  _globals['_MSGREVOKEALLOWANCE']._serialized_end=629
  _globals['_MSGREVOKEALLOWANCERESPONSE']._serialized_start=631
  _globals['_MSGREVOKEALLOWANCERESPONSE']._serialized_end=659
  _globals['_MSGPRUNEALLOWANCES']._serialized_start=661
  _globals['_MSGPRUNEALLOWANCES']._serialized_end=744
  _globals['_MSGPRUNEALLOWANCESRESPONSE']._serialized_start=746
  _globals['_MSGPRUNEALLOWANCESRESPONSE']._serialized_end=774
  _globals['_MSG']._serialized_start=777
  _globals['_MSG']._serialized_end=1137
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cometbft/types/v1beta1/events.proto\x12\x16\x63ometbft.types.v1beta1\"W\n\x13\x45ventDataRoundState\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x12\n\x04step\x18\x03 \x01(\tR\x04stepB\xdc\x01\n\x1a\x63om.cometbft.types.v1beta1B\x0b\x45ventsProtoP\x01Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1\xa2\x02\x03\x43TX\xaa\x02\x16\x43ometbft.Types.V1beta1\xca\x02\x16\x43ometbft\\Types\\V1beta1\xe2\x02\"Cometbft\\Types\\V1beta1\\GPBMetadata\xea\x02\x18\x43ometbft::Types::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cometbft.types.v1beta1B\013EventsProtoP\001Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1\242\002\003CTX\252\002\026Cometbft.Types.V1beta1\312\002\026Cometbft\\Types\\V1beta1\342\002\"Cometbft\\Types\\V1beta1\\GPBMetadata\352\002\030Cometbft::Types::V1beta1'
  _globals['_EVENTDATAROUNDSTATE']._serialized_start=63
  _globals['_EVENTDATAROUNDSTATE']._serialized_end=150
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/app/v1alpha1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/app/v1alpha1/module.proto\x12\x13\x63osmos.app.v1alpha1\x1a google/protobuf/descriptor.proto\"\xc7\x01\n\x10ModuleDescriptor\x12\x1b\n\tgo_import\x18\x01 \x01(\tR\x08goImport\x12\x46\n\x0buse_package\x18\x02 \x03(\x0b\x32%.cosmos.app.v1alpha1.PackageReferenceR\nusePackage\x12N\n\x10\x63\x61n_migrate_from\x18\x03 \x03(\x0b\x32$.cosmos.app.v1alpha1.MigrateFromInfoR\x0e\x63\x61nMigrateFrom\"B\n\x10PackageReference\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08revision\x18\x02 \x01(\rR\x08revision\")\n\x0fMigrateFromInfo\x12\x16\n\x06module\x18\x01 \x01(\tR\x06module:a\n\x06module\x12\x1f.google.protobuf.MessageOptions\x18\x87\xe8\xa2\x1b \x01(\x0b\x32%.cosmos.app.v1alpha1.ModuleDescriptorR\x06moduleB\x94\x01\n\x17\x63om.cosmos.app.v1alpha1B\x0bModuleProtoP\x01\xa2\x02\x03\x43\x41X\xaa\x02\x13\x43osmos.App.V1alpha1\xca\x02\x13\x43osmos\\App\\V1alpha1\xe2\x02\x1f\x43osmos\\App\\V1alpha1\\GPBMetadata\xea\x02\x15\x43osmos::App::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.v1alpha1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.app.v1alpha1B\013ModuleProtoP\001\242\002\003CAX\252\002\023Cosmos.App.V1alpha1\312\002\023Cosmos\\App\\V1alpha1\342\002\037Cosmos\\App\\V1alpha1\\GPBMetadata\352\002\025Cosmos::App::V1alpha1'
  _globals['_MODULEDESCRIPTOR']._serialized_start=92
  _globals['_MODULEDESCRIPTOR']._serialized_end=291
  _globals['_PACKAGEREFERENCE']._serialized_start=293
  _globals['_PACKAGEREFERENCE']._serialized_end=359
  _globals['_MIGRATEFROMINFO']._serialized_start=361
  _globals['_MIGRATEFROMINFO']._serialized_end=402
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/source.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$google/api/expr/v1beta1/source.proto\x12\x17google.api.expr.v1beta1\"\xdb\x01\n\nSourceInfo\x12\x1a\n\x08location\x18\x02 \x01(\tR\x08location\x12!\n\x0cline_offsets\x18\x03 \x03(\x05R\x0blineOffsets\x12P\n\tpositions\x18\x04 \x03(\x0b\x32\x32.google.api.expr.v1beta1.SourceInfo.PositionsEntryR\tpositions\x1a<\n\x0ePositionsEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"p\n\x0eSourcePosition\x12\x1a\n\x08location\x18\x01 \x01(\tR\x08location\x12\x16\n\x06offset\x18\x02 \x01(\x05R\x06offset\x12\x12\n\x04line\x18\x03 \x01(\x05R\x04line\x12\x16\n\x06\x63olumn\x18\x04 \x01(\x05R\x06\x63olumnB\xe9\x01\n\x1b\x63om.google.api.expr.v1beta1B\x0bSourceProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x17Google.Api.Expr.V1beta1\xca\x02\x17Google\\Api\\Expr\\V1beta1\xe2\x02#Google\\Api\\Expr\\V1beta1\\GPBMetadata\xea\x02\x1aGoogle::Api::Expr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.google.api.expr.v1beta1B\013SourceProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001\242\002\003GAE\252\002\027Google.Api.Expr.V1beta1\312\002\027Google\\Api\\Expr\\V1beta1\342\002#Google\\Api\\Expr\\V1beta1\\GPBMetadata\352\002\032Google::Api::Expr::V1beta1'
  _globals['_SOURCEINFO_POSITIONSENTRY']._loaded_options = None
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_options = b'8\001'
  _globals['_SOURCEINFO']._serialized_start=66
  _globals['_SOURCEINFO']._serialized_end=285
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_start=225
  _globals['_SOURCEINFO_POSITIONSENTRY']._serialized_end=285
  _globals['_SOURCEPOSITION']._serialized_start=287
  _globals['_SOURCEPOSITION']._serialized_end=399
# @@protoc_insertion_point(module_scope)



import asyncio
from typing import Callable, Optional

from google.protobuf import json_format
from grpc import RpcError

from pyinjective.core.network import CookieAssistant


class GrpcApiStreamAssistant:
    def __init__(self, cookie_assistant: CookieAssistant):
        super().__init__()
        self._cookie_assistant = cookie_assistant

    async def listen_stream(
        self,
        call: Callable,
        request,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
    ):
        metadata = self._cookie_assistant.metadata()
        stream = call(request, metadata=metadata)

        try:
            async for event in stream:
                parsed_event = json_format.MessageToDict(
                    message=event,
                    always_print_fields_with_no_presence=True,
                )
                if asyncio.iscoroutinefunction(callback):
                    await callback(parsed_event)
                else:
                    callback(parsed_event)
        except RpcError as ex:
            if on_status_callback is not None:
                if asyncio.iscoroutinefunction(on_status_callback):
                    await on_status_callback(ex)
                else:
                    on_status_callback(ex)

        if on_end_callback is not None:
            if asyncio.iscoroutinefunction(on_end_callback):
                await on_end_callback()
            else:
                on_end_callback()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1beta1/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cometbft/types/v1beta1/params.proto\x12\x16\x63ometbft.types.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"\xb0\x02\n\x0f\x43onsensusParams\x12?\n\x05\x62lock\x18\x01 \x01(\x0b\x32#.cometbft.types.v1beta1.BlockParamsB\x04\xc8\xde\x1f\x00R\x05\x62lock\x12H\n\x08\x65vidence\x18\x02 \x01(\x0b\x32&.cometbft.types.v1beta1.EvidenceParamsB\x04\xc8\xde\x1f\x00R\x08\x65vidence\x12K\n\tvalidator\x18\x03 \x01(\x0b\x32\'.cometbft.types.v1beta1.ValidatorParamsB\x04\xc8\xde\x1f\x00R\tvalidator\x12\x45\n\x07version\x18\x04 \x01(\x0b\x32%.cometbft.types.v1beta1.VersionParamsB\x04\xc8\xde\x1f\x00R\x07version\"e\n\x0b\x42lockParams\x12\x1b\n\tmax_bytes\x18\x01 \x01(\x03R\x08maxBytes\x12\x17\n\x07max_gas\x18\x02 \x01(\x03R\x06maxGas\x12 \n\x0ctime_iota_ms\x18\x03 \x01(\x03R\ntimeIotaMs\"\xa9\x01\n\x0e\x45videnceParams\x12+\n\x12max_age_num_blocks\x18\x01 \x01(\x03R\x0fmaxAgeNumBlocks\x12M\n\x10max_age_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01R\x0emaxAgeDuration\x12\x1b\n\tmax_bytes\x18\x03 \x01(\x03R\x08maxBytes\"?\n\x0fValidatorParams\x12\"\n\rpub_key_types\x18\x01 \x03(\tR\x0bpubKeyTypes:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\"+\n\rVersionParams\x12\x10\n\x03\x61pp\x18\x01 \x01(\x04R\x03\x61pp:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\"Z\n\x0cHashedParams\x12&\n\x0f\x62lock_max_bytes\x18\x01 \x01(\x03R\rblockMaxBytes\x12\"\n\rblock_max_gas\x18\x02 \x01(\x03R\x0b\x62lockMaxGasB\xe0\x01\n\x1a\x63om.cometbft.types.v1beta1B\x0bParamsProtoP\x01Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1\xa2\x02\x03\x43TX\xaa\x02\x16\x43ometbft.Types.V1beta1\xca\x02\x16\x43ometbft\\Types\\V1beta1\xe2\x02\"Cometbft\\Types\\V1beta1\\GPBMetadata\xea\x02\x18\x43ometbft::Types::V1beta1\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1beta1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cometbft.types.v1beta1B\013ParamsProtoP\001Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1\242\002\003CTX\252\002\026Cometbft.Types.V1beta1\312\002\026Cometbft\\Types\\V1beta1\342\002\"Cometbft\\Types\\V1beta1\\GPBMetadata\352\002\030Cometbft::Types::V1beta1\250\342\036\001'
  _globals['_CONSENSUSPARAMS'].fields_by_name['block']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['block']._serialized_options = b'\310\336\037\000'
  _globals['_CONSENSUSPARAMS'].fields_by_name['evidence']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_CONSENSUSPARAMS'].fields_by_name['validator']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_CONSENSUSPARAMS'].fields_by_name['version']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._loaded_options = None
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_VALIDATORPARAMS']._loaded_options = None
  _globals['_VALIDATORPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_VERSIONPARAMS']._loaded_options = None
  _globals['_VERSIONPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=118
  _globals['_CONSENSUSPARAMS']._serialized_end=422
  _globals['_BLOCKPARAMS']._serialized_start=424
  _globals['_BLOCKPARAMS']._serialized_end=525
  _globals['_EVIDENCEPARAMS']._serialized_start=528
  _globals['_EVIDENCEPARAMS']._serialized_end=697
  _globals['_VALIDATORPARAMS']._serialized_start=699
  _globals['_VALIDATORPARAMS']._serialized_end=762
  _globals['_VERSIONPARAMS']._serialized_start=764
  _globals['_VERSIONPARAMS']._serialized_end=807
  _globals['_HASHEDPARAMS']._serialized_start=809
  _globals['_HASHEDPARAMS']._serialized_end=899
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.cosmwasm.wasm.v1 import tx_pb2 as cosmwasm_dot_wasm_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the wasm Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StoreCode = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/StoreCode',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCode.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCodeResponse.FromString,
                _registered_method=True)
        self.InstantiateContract = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/InstantiateContract',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContractResponse.FromString,
                _registered_method=True)
        self.InstantiateContract2 = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/InstantiateContract2',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract2.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract2Response.FromString,
                _registered_method=True)
        self.ExecuteContract = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/ExecuteContract',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgExecuteContract.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgExecuteContractResponse.FromString,
                _registered_method=True)
        self.MigrateContract = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/MigrateContract',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContract.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContractResponse.FromString,
                _registered_method=True)
        self.UpdateAdmin = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/UpdateAdmin',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateAdmin.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateAdminResponse.FromString,
                _registered_method=True)
        self.ClearAdmin = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/ClearAdmin',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgClearAdmin.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgClearAdminResponse.FromString,
                _registered_method=True)
        self.UpdateInstantiateConfig = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/UpdateInstantiateConfig',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateInstantiateConfig.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateInstantiateConfigResponse.FromString,
                _registered_method=True)
        self.UpdateParams = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/UpdateParams',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.SudoContract = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/SudoContract',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgSudoContract.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgSudoContractResponse.FromString,
                _registered_method=True)
        self.PinCodes = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/PinCodes',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgPinCodes.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgPinCodesResponse.FromString,
                _registered_method=True)
        self.UnpinCodes = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/UnpinCodes',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUnpinCodes.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUnpinCodesResponse.FromString,
                _registered_method=True)
        self.StoreAndInstantiateContract = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/StoreAndInstantiateContract',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndInstantiateContract.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndInstantiateContractResponse.FromString,
                _registered_method=True)
        self.RemoveCodeUploadParamsAddresses = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/RemoveCodeUploadParamsAddresses',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveCodeUploadParamsAddresses.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveCodeUploadParamsAddressesResponse.FromString,
                _registered_method=True)
        self.AddCodeUploadParamsAddresses = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/AddCodeUploadParamsAddresses',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgAddCodeUploadParamsAddresses.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgAddCodeUploadParamsAddressesResponse.FromString,
                _registered_method=True)
        self.StoreAndMigrateContract = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/StoreAndMigrateContract',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndMigrateContract.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndMigrateContractResponse.FromString,
                _registered_method=True)
        self.UpdateContractLabel = channel.unary_unary(
                '/cosmwasm.wasm.v1.Msg/UpdateContractLabel',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateContractLabel.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateContractLabelResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the wasm Msg service.
    """

    def StoreCode(self, request, context):
        """StoreCode to submit Wasm code to the system
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstantiateContract(self, request, context):
        """InstantiateContract creates a new smart contract instance for the given
        code id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstantiateContract2(self, request, context):
        """InstantiateContract2 creates a new smart contract instance for the given
        code id with a predictable address
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteContract(self, request, context):
        """Execute submits the given message data to a smart contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MigrateContract(self, request, context):
        """Migrate runs a code upgrade/ downgrade for a smart contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAdmin(self, request, context):
        """UpdateAdmin sets a new admin for a smart contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearAdmin(self, request, context):
        """ClearAdmin removes any admin stored for a smart contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInstantiateConfig(self, request, context):
        """UpdateInstantiateConfig updates instantiate config for a smart contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines a governance operation for updating the x/wasm
        module parameters. The authority is defined in the keeper.

        Since: 0.40
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SudoContract(self, request, context):
        """SudoContract defines a governance operation for calling sudo
        on a contract. The authority is defined in the keeper.

        Since: 0.40
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PinCodes(self, request, context):
        """PinCodes defines a governance operation for pinning a set of
        code ids in the wasmvm cache. The authority is defined in the keeper.

        Since: 0.40
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnpinCodes(self, request, context):
        """UnpinCodes defines a governance operation for unpinning a set of
        code ids in the wasmvm cache. The authority is defined in the keeper.

        Since: 0.40
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StoreAndInstantiateContract(self, request, context):
        """StoreAndInstantiateContract defines a governance operation for storing
        and instantiating the contract. The authority is defined in the keeper.

        Since: 0.40
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveCodeUploadParamsAddresses(self, request, context):
        """RemoveCodeUploadParamsAddresses defines a governance operation for
        removing addresses from code upload params.
        The authority is defined in the keeper.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddCodeUploadParamsAddresses(self, request, context):
        """AddCodeUploadParamsAddresses defines a governance operation for
        adding addresses to code upload params.
        The authority is defined in the keeper.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StoreAndMigrateContract(self, request, context):
        """StoreAndMigrateContract defines a governance operation for storing
        and migrating the contract. The authority is defined in the keeper.

        Since: 0.42
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateContractLabel(self, request, context):
        """UpdateContractLabel sets a new label for a smart contract

        Since: 0.43
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StoreCode': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreCode,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCode.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCodeResponse.SerializeToString,
            ),
            'InstantiateContract': grpc.unary_unary_rpc_method_handler(
                    servicer.InstantiateContract,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContractResponse.SerializeToString,
            ),
            'InstantiateContract2': grpc.unary_unary_rpc_method_handler(
                    servicer.InstantiateContract2,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract2.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract2Response.SerializeToString,
            ),
            'ExecuteContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteContract,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgExecuteContract.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgExecuteContractResponse.SerializeToString,
            ),
            'MigrateContract': grpc.unary_unary_rpc_method_handler(
                    servicer.MigrateContract,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContract.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContractResponse.SerializeToString,
            ),
            'UpdateAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAdmin,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateAdmin.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateAdminResponse.SerializeToString,
            ),
            'ClearAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearAdmin,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgClearAdmin.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgClearAdminResponse.SerializeToString,
            ),
            'UpdateInstantiateConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInstantiateConfig,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateInstantiateConfig.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateInstantiateConfigResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'SudoContract': grpc.unary_unary_rpc_method_handler(
                    servicer.SudoContract,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgSudoContract.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgSudoContractResponse.SerializeToString,
            ),
            'PinCodes': grpc.unary_unary_rpc_method_handler(
                    servicer.PinCodes,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgPinCodes.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgPinCodesResponse.SerializeToString,
            ),
            'UnpinCodes': grpc.unary_unary_rpc_method_handler(
                    servicer.UnpinCodes,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUnpinCodes.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUnpinCodesResponse.SerializeToString,
            ),
            'StoreAndInstantiateContract': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreAndInstantiateContract,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndInstantiateContract.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndInstantiateContractResponse.SerializeToString,
            ),
            'RemoveCodeUploadParamsAddresses': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveCodeUploadParamsAddresses,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveCodeUploadParamsAddresses.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveCodeUploadParamsAddressesResponse.SerializeToString,
            ),
            'AddCodeUploadParamsAddresses': grpc.unary_unary_rpc_method_handler(
                    servicer.AddCodeUploadParamsAddresses,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgAddCodeUploadParamsAddresses.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgAddCodeUploadParamsAddressesResponse.SerializeToString,
            ),
            'StoreAndMigrateContract': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreAndMigrateContract,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndMigrateContract.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndMigrateContractResponse.SerializeToString,
            ),
            'UpdateContractLabel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateContractLabel,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateContractLabel.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateContractLabelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmwasm.wasm.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmwasm.wasm.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the wasm Msg service.
    """

    @staticmethod
    def StoreCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/StoreCode',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCode.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InstantiateContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/InstantiateContract',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InstantiateContract2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/InstantiateContract2',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract2.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgInstantiateContract2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExecuteContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/ExecuteContract',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgExecuteContract.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgExecuteContractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MigrateContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/MigrateContract',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContract.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgMigrateContractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/UpdateAdmin',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateAdmin.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateAdminResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClearAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/ClearAdmin',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgClearAdmin.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgClearAdminResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateInstantiateConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/UpdateInstantiateConfig',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateInstantiateConfig.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateInstantiateConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/UpdateParams',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SudoContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/SudoContract',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgSudoContract.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgSudoContractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PinCodes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/PinCodes',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgPinCodes.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgPinCodesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnpinCodes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/UnpinCodes',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUnpinCodes.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUnpinCodesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StoreAndInstantiateContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/StoreAndInstantiateContract',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndInstantiateContract.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndInstantiateContractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveCodeUploadParamsAddresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/RemoveCodeUploadParamsAddresses',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveCodeUploadParamsAddresses.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgRemoveCodeUploadParamsAddressesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddCodeUploadParamsAddresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/AddCodeUploadParamsAddresses',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgAddCodeUploadParamsAddresses.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgAddCodeUploadParamsAddressesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StoreAndMigrateContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/StoreAndMigrateContract',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndMigrateContract.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgStoreAndMigrateContractResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateContractLabel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Msg/UpdateContractLabel',
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateContractLabel.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_tx__pb2.MsgUpdateContractLabelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from typing import Any, Callable, Dict, List, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.cosmos.bank.v1beta1 import query_pb2 as bank_query_pb, query_pb2_grpc as bank_query_grpc
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcBankApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = bank_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = bank_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._stub.Params, request=request)

        return response

    async def fetch_balance(self, account_address: str, denom: str) -> Dict[str, Any]:
        request = bank_query_pb.QueryBalanceRequest(address=account_address, denom=denom)
        response = await self._execute_call(call=self._stub.Balance, request=request)

        return response

    async def fetch_balances(self, account_address: str) -> Dict[str, Any]:
        request = bank_query_pb.QueryAllBalancesRequest(address=account_address)
        response = await self._execute_call(call=self._stub.AllBalances, request=request)

        return response

    async def fetch_spendable_balances(
        self,
        account_address: str,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = bank_query_pb.QuerySpendableBalancesRequest(
            address=account_address,
            pagination=pagination_request,
        )
        response = await self._execute_call(call=self._stub.SpendableBalances, request=request)

        return response

    async def fetch_spendable_balances_by_denom(
        self,
        account_address: str,
        denom: str,
    ) -> Dict[str, Any]:
        request = bank_query_pb.QuerySpendableBalanceByDenomRequest(
            address=account_address,
            denom=denom,
        )
        response = await self._execute_call(call=self._stub.SpendableBalanceByDenom, request=request)

        return response

    async def fetch_total_supply(self, pagination: Optional[PaginationOption] = None) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = bank_query_pb.QueryTotalSupplyRequest(pagination=pagination_request)
        response = await self._execute_call(call=self._stub.TotalSupply, request=request)

        return response

    async def fetch_supply_of(self, denom: str) -> Dict[str, Any]:
        request = bank_query_pb.QuerySupplyOfRequest(denom=denom)
        response = await self._execute_call(call=self._stub.SupplyOf, request=request)

        return response

    async def fetch_denom_metadata(self, denom: str) -> Dict[str, Any]:
        request = bank_query_pb.QueryDenomMetadataRequest(denom=denom)
        response = await self._execute_call(call=self._stub.DenomMetadata, request=request)

        return response

    async def fetch_denoms_metadata(self, pagination: Optional[PaginationOption] = None) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = bank_query_pb.QueryDenomsMetadataRequest(pagination=pagination_request)
        response = await self._execute_call(call=self._stub.DenomsMetadata, request=request)

        return response

    async def fetch_denom_owners(self, denom: str, pagination: Optional[PaginationOption] = None) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = bank_query_pb.QueryDenomOwnersRequest(denom=denom, pagination=pagination_request)
        response = await self._execute_call(call=self._stub.DenomOwners, request=request)

        return response

    async def fetch_send_enabled(
        self,
        denoms: Optional[List[str]] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = bank_query_pb.QuerySendEnabledRequest(denoms=denoms, pagination=pagination_request)
        response = await self._execute_call(call=self._stub.SendEnabled, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/rpc/context/attribute_context.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*google/rpc/context/attribute_context.proto\x12\x12google.rpc.context\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x81\x14\n\x10\x41ttributeContext\x12\x41\n\x06origin\x18\x07 \x01(\x0b\x32).google.rpc.context.AttributeContext.PeerR\x06origin\x12\x41\n\x06source\x18\x01 \x01(\x0b\x32).google.rpc.context.AttributeContext.PeerR\x06source\x12K\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32).google.rpc.context.AttributeContext.PeerR\x0b\x64\x65stination\x12\x46\n\x07request\x18\x03 \x01(\x0b\x32,.google.rpc.context.AttributeContext.RequestR\x07request\x12I\n\x08response\x18\x04 \x01(\x0b\x32-.google.rpc.context.AttributeContext.ResponseR\x08response\x12I\n\x08resource\x18\x05 \x01(\x0b\x32-.google.rpc.context.AttributeContext.ResourceR\x08resource\x12:\n\x03\x61pi\x18\x06 \x01(\x0b\x32(.google.rpc.context.AttributeContext.ApiR\x03\x61pi\x12\x34\n\nextensions\x18\x08 \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensions\x1a\xf3\x01\n\x04Peer\x12\x0e\n\x02ip\x18\x01 \x01(\tR\x02ip\x12\x12\n\x04port\x18\x02 \x01(\x03R\x04port\x12M\n\x06labels\x18\x06 \x03(\x0b\x32\x35.google.rpc.context.AttributeContext.Peer.LabelsEntryR\x06labels\x12\x1c\n\tprincipal\x18\x07 \x01(\tR\tprincipal\x12\x1f\n\x0bregion_code\x18\x08 \x01(\tR\nregionCode\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1as\n\x03\x41pi\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12\x1c\n\toperation\x18\x02 \x01(\tR\toperation\x12\x1a\n\x08protocol\x18\x03 \x01(\tR\x08protocol\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\x1a\xb6\x01\n\x04\x41uth\x12\x1c\n\tprincipal\x18\x01 \x01(\tR\tprincipal\x12\x1c\n\taudiences\x18\x02 \x03(\tR\taudiences\x12\x1c\n\tpresenter\x18\x03 \x01(\tR\tpresenter\x12/\n\x06\x63laims\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x06\x63laims\x12#\n\raccess_levels\x18\x05 \x03(\tR\x0c\x61\x63\x63\x65ssLevels\x1a\xcf\x03\n\x07Request\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06method\x18\x02 \x01(\tR\x06method\x12S\n\x07headers\x18\x03 \x03(\x0b\x32\x39.google.rpc.context.AttributeContext.Request.HeadersEntryR\x07headers\x12\x12\n\x04path\x18\x04 \x01(\tR\x04path\x12\x12\n\x04host\x18\x05 \x01(\tR\x04host\x12\x16\n\x06scheme\x18\x06 \x01(\tR\x06scheme\x12\x14\n\x05query\x18\x07 \x01(\tR\x05query\x12.\n\x04time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04time\x12\x12\n\x04size\x18\n \x01(\x03R\x04size\x12\x1a\n\x08protocol\x18\x0b \x01(\tR\x08protocol\x12\x16\n\x06reason\x18\x0c \x01(\tR\x06reason\x12=\n\x04\x61uth\x18\r \x01(\x0b\x32).google.rpc.context.AttributeContext.AuthR\x04\x61uth\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\xb8\x02\n\x08Response\x12\x12\n\x04\x63ode\x18\x01 \x01(\x03R\x04\x63ode\x12\x12\n\x04size\x18\x02 \x01(\x03R\x04size\x12T\n\x07headers\x18\x03 \x03(\x0b\x32:.google.rpc.context.AttributeContext.Response.HeadersEntryR\x07headers\x12.\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04time\x12\x42\n\x0f\x62\x61\x63kend_latency\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0e\x62\x61\x63kendLatency\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x98\x05\n\x08Resource\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12Q\n\x06labels\x18\x04 \x03(\x0b\x32\x39.google.rpc.context.AttributeContext.Resource.LabelsEntryR\x06labels\x12\x10\n\x03uid\x18\x05 \x01(\tR\x03uid\x12`\n\x0b\x61nnotations\x18\x06 \x03(\x0b\x32>.google.rpc.context.AttributeContext.Resource.AnnotationsEntryR\x0b\x61nnotations\x12!\n\x0c\x64isplay_name\x18\x07 \x01(\tR\x0b\x64isplayName\x12;\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12;\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x12;\n\x0b\x64\x65lete_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ndeleteTime\x12\x12\n\x04\x65tag\x18\x0b \x01(\tR\x04\x65tag\x12\x1a\n\x08location\x18\x0c \x01(\tR\x08location\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xf3\x01\n\x16\x63om.google.rpc.contextB\x15\x41ttributeContextProtoP\x01ZUgoogle.golang.org/genproto/googleapis/rpc/context/attribute_context;attribute_context\xf8\x01\x01\xa2\x02\x03GRC\xaa\x02\x12Google.Rpc.Context\xca\x02\x12Google\\Rpc\\Context\xe2\x02\x1eGoogle\\Rpc\\Context\\GPBMetadata\xea\x02\x14Google::Rpc::Contextb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.rpc.context.attribute_context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.google.rpc.contextB\025AttributeContextProtoP\001ZUgoogle.golang.org/genproto/googleapis/rpc/context/attribute_context;attribute_context\370\001\001\242\002\003GRC\252\002\022Google.Rpc.Context\312\002\022Google\\Rpc\\Context\342\002\036Google\\Rpc\\Context\\GPBMetadata\352\002\024Google::Rpc::Context'
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT']._serialized_start=189
  _globals['_ATTRIBUTECONTEXT']._serialized_end=2750
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_start=757
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_end=1000
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_start=943
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_end=1000
  _globals['_ATTRIBUTECONTEXT_API']._serialized_start=1002
  _globals['_ATTRIBUTECONTEXT_API']._serialized_end=1117
  _globals['_ATTRIBUTECONTEXT_AUTH']._serialized_start=1120
  _globals['_ATTRIBUTECONTEXT_AUTH']._serialized_end=1302
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_start=1305
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_end=1768
  _globals['_ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY']._serialized_start=1710
  _globals['_ATTRIBUTECONTEXT_REQUEST_HEADERSENTRY']._serialized_end=1768
  _globals['_ATTRIBUTECONTEXT_RESPONSE']._serialized_start=1771
  _globals['_ATTRIBUTECONTEXT_RESPONSE']._serialized_end=2083
  _globals['_ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY']._serialized_start=1710
  _globals['_ATTRIBUTECONTEXT_RESPONSE_HEADERSENTRY']._serialized_end=1768
  _globals['_ATTRIBUTECONTEXT_RESOURCE']._serialized_start=2086
  _globals['_ATTRIBUTECONTEXT_RESOURCE']._serialized_end=2750
  _globals['_ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY']._serialized_start=943
  _globals['_ATTRIBUTECONTEXT_RESOURCE_LABELSENTRY']._serialized_end=1000
  _globals['_ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY']._serialized_start=2688
  _globals['_ATTRIBUTECONTEXT_RESOURCE_ANNOTATIONSENTRY']._serialized_end=2750
# @@protoc_insertion_point(module_scope)
